@@ -72,7 +72,7 @@ _mssp_endpoints = [
     ]
   ],
   [
-    "getCIDGroupMembersBy",
+    "getCIDGroupMembersByV1",
     "GET",
     "/mssp/entities/cid-group-members/v1",
     "Get CID group members by CID group ID.",
@@ -119,6 +119,26 @@ _mssp_endpoints = [
       }
     ]
   ],
+  [
+    "getCIDGroupMembersBy",
+    "GET",
+    "/mssp/entities/cid-group-members/v2",
+    "Get CID group members by CID Group ID.",
+    "mssp",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "CID group IDs search for",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "getCIDGroupMembersByV2",
     "GET",
@@ -140,7 +160,7 @@ _mssp_endpoints = [
     ]
   ],
   [
-    "getCIDGroupById",
+    "getCIDGroupByIdV1",
     "GET",
     "/mssp/entities/cid-groups/v1",
     "Get CID groups by ID.",
@@ -208,6 +228,26 @@ _mssp_endpoints = [
       }
     ]
   ],
+  [
+    "getCIDGroupById",
+    "GET",
+    "/mssp/entities/cid-groups/v2",
+    "Get CID Groups by ID.",
+    "mssp",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "CID group IDs to search for",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "getCIDGroupByIdV2",
     "GET",
@@ -280,7 +320,7 @@ _mssp_endpoints = [
     ]
   ],
   [
-    "getUserGroupMembersByID",
+    "getUserGroupMembersByIDV1",
     "GET",
     "/mssp/entities/user-group-members/v1",
     "Get user group members by user group ID.",
@@ -327,6 +367,26 @@ _mssp_endpoints = [
       }
     ]
   ],
+  [
+    "getUserGroupMembersByID",
+    "GET",
+    "/mssp/entities/user-group-members/v2",
+    "Get user group members by user group ID.",
+    "mssp",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "User group IDs to search for",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "getUserGroupMembersByIDV2",
     "GET",
@@ -348,7 +408,7 @@ _mssp_endpoints = [
     ]
   ],
   [
-    "getUserGroupsByID",
+    "getUserGroupsByIDV1",
     "GET",
     "/mssp/entities/user-groups/v1",
     "Get user groups by ID.",
@@ -416,6 +476,26 @@ _mssp_endpoints = [
       }
     ]
   ],
+  [
+    "getUserGroupsByID",
+    "GET",
+    "/mssp/entities/user-groups/v2",
+    "Get user groups by ID.",
+    "mssp",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "User group IDs to search for",
+        "name": "ids",
+        "in": "query",
+        "required": True
+      }
+    ]
+  ],
   [
     "getUserGroupsByIDV2",
     "GET",
