@@ -162,12 +162,6 @@ _sample_uploads_endpoints = [
     "making it available for content analysis.",
     "sample_uploads",
     [
-      {
-        "description": "Source of archive.",
-        "name": "source",
-        "in": "formData",
-        "required": True
-      },
       {
         "type": "file",
         "description": "Content of the uploaded archive. For example, use `--form file=@$FILE_PATH` when using cURL.",
